@@ -4,6 +4,10 @@ from peewee import Model, EXCLUDED
 
 class BaseModel(Model):
     def bulk_save(self, rows: list, transaction_count=None):
+
+        if not rows:
+            return
+
         conflict_fields = self.get_model_indexes()
         update_fields = self.get_excluded_fields()
 
@@ -22,7 +26,7 @@ class BaseModel(Model):
                     update=update_fields,
                 ).execute()
             else:
-                self.insert_many(rows[index:index + transaction_count]).execute()
+                self.insert_many(rows[index:index + transaction_count]).on_conflict_ignore().execute()
 
     def save_or_update(self, row):
         conflict_fields = self.get_model_indexes()
